@@ -3,14 +3,9 @@ from __future__ import absolute_import, unicode_literals
 from django.conf import settings
 from django.contrib import admin
 from django.urls import include, re_path
-from wagtail import VERSION as WAGTAIL_VERSION
+
+from wagtail import urls as wagtail_urls
 from wagtail.admin import urls as wagtailadmin_urls
-
-if WAGTAIL_VERSION >= (3, 0):
-    from wagtail import urls as wagtail_urls
-else:
-    from wagtail.core import urls as wagtail_urls
-
 from wagtail.documents import urls as wagtaildocs_urls
 
 urlpatterns = [
