@@ -1,7 +1,5 @@
 import os
 
-from wagtail import VERSION as WAGTAIL_VERSION
-
 TESTS_DIR = os.path.dirname(os.path.abspath(__file__))
 BASE_DIR = os.path.dirname(TESTS_DIR)
 
@@ -16,7 +14,7 @@ INSTALLED_APPS = [
     'wagtail.images',
     'wagtail.search',
     'wagtail.admin',
-    'wagtail' if WAGTAIL_VERSION >= (3, 0) else 'wagtail.core',
+    'wagtail',
     'wagtail.contrib.settings',
 
     'modelcluster',
@@ -38,8 +36,7 @@ MIDDLEWARE = [
     'django.contrib.auth.middleware.SessionAuthenticationMiddleware',
     'django.middleware.security.SecurityMiddleware',
     'django.contrib.messages.middleware.MessageMiddleware',
-
-    'wagtail.middleware.SiteMiddleware' if WAGTAIL_VERSION >= (3, 0) else 'wagtail.core.middleware.SiteMiddleware',
+    'wagtail.middleware.SiteMiddleware',
 ]
 
 ROOT_URLCONF = 'tests.app.urls'
@@ -90,10 +87,7 @@ MEDIA_URL = '/media/'
 
 WAGTAIL_SITE_NAME = "Wagtail Schema.org test suite"
 
-if WAGTAIL_VERSION >= (3, 0):
-    WAGTAILADMIN_BASE_URL = 'http://example.com'
-else:
-    BASE_URL = 'http://example.com'
+WAGTAILADMIN_BASE_URL = 'http://example.com'
 
 DEBUG = True
 
