@@ -1,9 +1,4 @@
-from wagtail import VERSION as WAGTAIL_VERSION
-
-if WAGTAIL_VERSION >= (4, 0):
-    from wagtail.contrib.settings.models import BaseSiteSetting
-else:
-    from wagtail.contrib.settings.models import BaseSetting as BaseSiteSetting
+from wagtail.contrib.settings.models import BaseSiteSetting
 
 from .jsonld import ThingLD
 from .registry import SiteThingLD
